const { InputManager } = require ('./input_manager')
const { ResourceManager } = require('./resource_manager')
const { Player } = require('./player')
const config = require('../config.json')

class GuildsManager {
  #guilds

  constructor() {
    this.#guilds = {}
  }

  toString() {
    return "GuildsManager#" + Object.keys(this.#guilds).map(g => `[guid:${g}]`)
  }

  get_manager(guild, name) {
    return this.#guilds[guild][name];
  }

  async handle_message(message) {
    const guild_id = message.guild.id
    if (!this.#guilds[guild_id]) {
      const current_config = config[message.guild.id] || config['default']
      this.#guilds[guild_id] = {
        input: new InputManager(this, current_config),
        player: new Player(this),
        resource: new ResourceManager(this)
      }
    }
    const player_action = await this.#guilds[guild_id].input.handle_message(message)
    console.log("player_action", player_action)
    if (player_action) {
      if (!this.#guilds[guild_id]?.[player_action.target]?.[player_action.action]) {
        message.channel.send(`The command ${player_action.target} ${player_action.action} is not implemented yet`)
      } else {
        const output = await this.#guilds[guild_id][player_action.target][player_action.action](message, player_action.params)
        return output
      }
    }
  }
}

module.exports = { GuildsManager }
