const { Playlist } = require('./playlist')
const { GuildAction } = require('./guild_action')

class InputManager {
  #config
  #triggers
  #gmanager

  constructor(gmanager, config) {
    this.#config = config
    this.#gmanager = gmanager
    this.#triggers = []
  }

  async handle_message(message) {
    const [command, ...command_params] = message.content.split(/\s+/)
    console.error("> command", command)
    const command_target_action = this.#config.commands[command]
    console.error("> command_target_action", command_target_action)
    if (command_target_action) {
      return new GuildAction({ ...command_target_action, params: command_params })
    }

    const trigger_target_action_idx = this.#triggers.findIndex(t => t.pattern.test(command))
    // TODO: add user, etc check
    if (trigger_target_action_idx > -1) {
      const trigger_target_action = this.#triggers[trigger_target_action_idx]
      console.error("> trigger_target_action", trigger_target_action)
      if (trigger_target_action.one_use) {
        delete this.#triggers[trigger_target_action_idx]
        this.#triggers = this.#triggers.filter(Boolean)
      }
      return new GuildAction({ ...trigger_target_action, params: command_params })
    }
    return null
  }

  add_trigger({ pattern, target, action, ttl = '1 hour', user_shared = false, one_use = true }) {
    this.#triggers.push({
      pattern,
      target,
      action,
      ttl,
      user_shared,
      one_use,
    })
    // TODO add async loop to cleanup triggers by ttl
  }
}

module.exports = { InputManager }
