const fetch = require('node-fetch')

class ResourceManager {
  #gmanager

  constructor(gmanager) {
    this.#gmanager = gmanager
  }

  async #search_youtube(search) {
    try {
      const req = await fetch('https://www.youtube.com/results?search_query='
                              + encodeURIComponent(search))
      const body = await req.text()
      const json = JSON.parse(body.match(/ytInitialData = (.*);<\/script>/)[1])
      const results = json.contents.twoColumnSearchResultsRenderer.primaryContents.sectionListRenderer.contents[0].itemSectionRenderer.contents
      return results
        .filter(e => e.videoRenderer)
        .map(e => {
          return {url: 'https://www.youtube.com/watch?v=' + e.videoRenderer.videoId,
                  title: e.videoRenderer.title.runs[0].text,
                  length: e.videoRenderer.lengthText.simpleText,
                  source: 'youtube'}
        })
    } catch(e) {
      return []
    }
  }

  async search(message, args) {
    const json_res = await this.#search_youtube(args.join(' '))
    if (json_res.length === 0) {
      message.channel.send(':warning: Something went wrong. Please try again')
    } else {
      const text_res = json_res
            .slice(0, 10)
            .map((video, i) => `${i + 1}: ${video.title.replace(/[^A-Za-z0-9\-_]+/g, " ")} (${video.length})`)
            .join("\n")
      // TODO: 2000 chars limit
      // TODO: find a better syntaxic coloration than js
      const input_manager = this.#gmanager.get_manager(message.guild.id, 'input')
      input_manager.add_trigger({
        pattern: /^\d+/,
        target: 'resource',
        action: 'search_confirm',
        ttl: '5 minutes',
        user_shared: false,
        one_use: true,
      })
      message.channel.send('```js\n' + text_res + '```')
    }
    return json_res
  }
}

module.exports = { ResourceManager }
